@@ -97,8 +97,7 @@ ordered_analysis_df = analysis_df[order(analysis_df$treat, decreasing = T),]
 
 optwt <- weightit(treat ~ log_re74 + log_re75,
                   data = ordered_analysis_df,
-                  method = "optweight", estimand = "ATE",
-                  tols = 0.005, include.obj = TRUE)
+                  method = "optweight", estimand = "ATE")
 # summary(optwt)
 
 optwt_df = ordered_analysis_df[, c(covariates, treatment, outcome)]
